[−][src]Struct source_error::Error
An Error type targetting errors tied to source file contents
Most of the utility of this type is in its implementation of Display which
renders the error next along with the relative line of code